@@ -1,7 +1,9 @@
 context("test join")
 
-## join returns either a sf object or a tibble
-data(xs)
+## generate fG_ssm obj a quickly as possible
+## have to do this to avoid error when calling st_transform on platforms running older GDAL versions (sese2 is highly sub-sampled for this purpose)
+xs <- fit_ssm(sese2, spdf=FALSE, model = "rw", time.step=72, 
+              control = ssm_control(se = FALSE, verbose = 0))
 data(xm)
 
 p <- join(xs, xm)
