@@ -2,7 +2,10 @@ context("test plot_mpm")
 
 ## expect plot is silent
 data(xm)
-data(xs)
+## generate fG_ssm obj a quickly as possible
+## have to do this to avoid error when calling st_transform on platforms running older GDAL versions (sese2 is highly sub-sampled for this purpose)
+xs <- fit_ssm(sese2, spdf=FALSE, model = "rw", time.step=72, 
+              control = ssm_control(se = FALSE, verbose = 0))
 
 ## plot gamma time-series on a single page
 tp <- plot(xm, pages = 1, ncol = 1)
